@@ -22,6 +22,7 @@
 #define CURLAUTH_NTLM_FIRST 0x070a06 /* Added in 7.10.6 */
 #define CURLAUTH_NTLM_WB_FIRST 0x071600 /* Added in 7.22.0 */
 #define CURLAUTH_ONLY_FIRST 0x071503 /* Added in 7.21.3 */
+#define CURLAUTH_AWS_SIGV4_FIRST 0x074b00 /* Added in 7.75.0 */
 #define CURLCLOSEPOLICY_CALLBACK_FIRST 0x070700 /* Added in 7.7 */
 #define CURLCLOSEPOLICY_LEAST_RECENTLY_USED_FIRST 0x070700 /* Added in 7.7 */
 #define CURLCLOSEPOLICY_LEAST_TRAFFIC_FIRST 0x070700 /* Added in 7.7 */
@@ -679,6 +680,7 @@
 #define CURLOPT_USERNAME_FIRST 0x071301 /* Added in 7.19.1 */
 #define CURLOPT_USERPWD_FIRST 0x070100 /* Added in 7.1 */
 #define CURLOPT_USE_SSL_FIRST 0x071100 /* Added in 7.17.0 */
+#define CURLOPT_AWS_SIGV4_FIRST 0x074b00 /* Added in 7.75.0 */
 #define CURLOPT_VERBOSE_FIRST 0x070100 /* Added in 7.1 */
 #define CURLOPT_WILDCARDMATCH_FIRST 0x071500 /* Added in 7.21.0 */
 #define CURLOPT_WRITEDATA_FIRST 0x070907 /* Added in 7.9.7 */
@@ -712,6 +714,7 @@
 #define CURLPROTO_FTP_FIRST 0x071304 /* Added in 7.19.4 */
 #define CURLPROTO_FTPS_FIRST 0x071304 /* Added in 7.19.4 */
 #define CURLPROTO_GOPHER_FIRST 0x071502 /* Added in 7.21.2 */
+#define CURLPROTO_GOPHERS_FIRST 0x074b00 /* Added in 7.75.0 */
 #define CURLPROTO_HTTP_FIRST 0x071304 /* Added in 7.19.4 */
 #define CURLPROTO_HTTPS_FIRST 0x071304 /* Added in 7.19.4 */
 #define CURLPROTO_IMAP_FIRST 0x071400 /* Added in 7.20.0 */
@@ -879,6 +882,7 @@
 #define CURLVERSION_FIFTH_FIRST 0x073900 /* Added in 7.57.0 */
 #define CURLVERSION_FIRST_FIRST 0x070a00 /* Added in 7.10 */
 #define CURLVERSION_FOURTH_FIRST 0x071001 /* Added in 7.16.1 */
+#define CURLVERSION_NINTH_FIRST 0x074b00 /* Added in 7.75.0 */
 #define CURLVERSION_NOW_FIRST 0x070a00 /* Added in 7.10 */
 #define CURLVERSION_SECOND_FIRST 0x070b01 /* Added in 7.11.1 */
 #define CURLVERSION_SEVENTH_FIRST 0x074600 /* Added in 7.70.0 */
